==> eclipse-emf_2.8.3.orig.tar.xz: eclipse-emf-2.8.3/plugins/org.eclipse.emf.ecore.xcore/src/org/eclipse/emf/ecore/xcore/mappings/XFeatureMapping.java <==
/**
 * Copyright (c) 2011-2012 Eclipse contributors and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 */
package org.eclipse.emf.ecore.xcore.mappings;


import org.eclipse.emf.codegen.ecore.genmodel.GenFeature;
import org.eclipse.emf.ecore.EStructuralFeature;
import org.eclipse.emf.ecore.xcore.util.XcoreJvmInferrer;
import org.eclipse.xtext.common.types.JvmOperation;


public class XFeatureMapping extends AbstractMapping
{
  private GenFeature genFeature;

  private EStructuralFeature eStructuralFeature;

  public GenFeature getGenFeature()
  {
    return genFeature;
  }

  public void setGenFeature(GenFeature genFeature)
  {
    this.genFeature = genFeature;
  }

  public JvmOperation getGetter()
  {
    return XcoreJvmInferrer.getInferredElement(genFeature, genFeature.getGenClass().getQualifiedInterfaceName() + "." + genFeature.getGetAccessor());
  }

  public JvmOperation getSetter()
  {
    return XcoreJvmInferrer.getInferredElement(genFeature, genFeature.getGenClass().getQualifiedInterfaceName() + ".set" + genFeature.getAccessorName());
  }

  public JvmOperation getIsSetter()
  {
    return XcoreJvmInferrer.getInferredElement(genFeature, genFeature.getGenClass().getQualifiedInterfaceName() + ".isSet" + genFeature.getAccessorName());
  }

  public JvmOperation getUnsetter()
  {
    return XcoreJvmInferrer.getInferredElement(genFeature, genFeature.getGenClass().getQualifiedInterfaceName() + ".unset" + genFeature.getAccessorName());
  }

  public EStructuralFeature getEStructuralFeature()
  {
    return eStructuralFeature;
  }

  public void setEStructuralFeature(EStructuralFeature eStructuralFeature)
  {
    this.eStructuralFeature = eStructuralFeature;
  }
}

==> eclipse-emf_2.42.0+dfsg.orig.tar.xz: eclipse-emf-2.42.0/plugins/org.eclipse.emf.ecore.xcore/src/org/eclipse/emf/ecore/xcore/mappings/XFeatureMapping.java <==
/**
 * Copyright (c) 2011-2012 Eclipse contributors and others.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v2.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v20.html
 */
package org.eclipse.emf.ecore.xcore.mappings;


import org.eclipse.emf.codegen.ecore.genmodel.GenFeature;
import org.eclipse.emf.ecore.EStructuralFeature;
import org.eclipse.xtext.common.types.JvmOperation;


public class XFeatureMapping extends AbstractMapping
{
  private GenFeature genFeature;

  private EStructuralFeature eStructuralFeature;

  private JvmOperation getter;

  private JvmOperation setter;

  private JvmOperation isSetter;

  private JvmOperation unsetter;

  public GenFeature getGenFeature()
  {
    return genFeature;
  }

  public void setGenFeature(GenFeature genFeature)
  {
    this.genFeature = genFeature;
  }

  public JvmOperation getGetter()
  {
    return getter;
  }

  public void setGetter(JvmOperation getter)
  {
    this.getter = getter;
  }

  public JvmOperation getSetter()
  {
    return setter;
  }

  public void setSetter(JvmOperation setter)
  {
    this.setter = setter;
  }

  public JvmOperation getIsSetter()
  {
    return isSetter;
  }

  public void setIsSetter(JvmOperation isSetter)
  {
    this.isSetter = isSetter;
  }

  public JvmOperation getUnsetter()
  {
    return unsetter;
  }

  public void setUnsetter(JvmOperation unsetter)
  {
    this.unsetter = unsetter;
  }

  public EStructuralFeature getEStructuralFeature()
  {
    return eStructuralFeature;
  }

  public void setEStructuralFeature(EStructuralFeature eStructuralFeature)
  {
    this.eStructuralFeature = eStructuralFeature;
  }
}
